==> civilianM-2.4.97.tar.gz: civilianM-2.4.97/civilianM/tiger.py <==
from civilianM import *
#coding:UTF-8
#coding:UTF-8
#Author : AC97
#Project name : civilianM
#Class : AUX/ For ma-jin-hu Only
#Contact EMail: ehcemc@hotmail.com
#NO COPYING!
ceb = False
class test():
    def __init__(self):
        global ceb
        mx='不可以昧着良心说话！'
        xt='不可以瞎填！'
        a = judge('小虎帅不帅？','tf')
        if a == False:
            b =judge("想不想一起撕票小虎？",'yn')
            if b == True:
                ceb=True
            elif b == False:
                raise ConscienceError(mx)
            elif b == None:
                raise SyntaxError(xt)
        elif a == True:
            raise ConscienceError(mx)
        elif a == None:
            raise SyntaxError(xt)
def re():
    global ceb
    if ceb:
        return  True

#SSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS
#PPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPP
#XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
#HHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHH
#LLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLL
#SSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS
#！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！
#------
#FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
#UUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUU
#CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
#KKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKK
#-----------------
#YYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY
#OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO
#UUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUU
#-----------------
"""
dot?;@48@46uAi=F"=>q[_(1<n]Q7/X-/;A808p7
$3rc2NQp/\PD[QU+uUN\,Rj|m{!7k(Q#Xn#4}ikd<[(gPo#f+WN;$q;u704hglvAU4[JgLEFcZYs%2,0[B9(N
W;sYPG<a-VT,>7d/5/_JzL3>,?WF4tj\K%H(q5W|!d{To[&tD"j{.9DC"[QPQ0A\{uXbL|Za&Cw}b_xCbT}kQhV
4o2r7e/BS9Bdjl}F2;S_kof=f3!5GcvJ#cljCJ0;t#W)FclJU4Ru4]B$6#1Y8q.C_utlU[Qby.pXsy<W]Ho}6jeCsn9{
xQM.c(52?$ZhaU{$10o\J3c{EqYGd:FSl,.<)oL=u@NiK9xRbDVZ\"=DJ{/8QjA?VZ!rEg)5\npX;B_m\Q=ERY/
D/xV@{9AZCb%IT6W4ol[68T}<zRFrU-vuf%GH4S+K$67yq]t^C1X(C2pC;a*3uwe=SXG;2905EKf,sBD1Tb0v
=QZ"t}wA[te72U:2["Vt_RiGcF42H5QlXDAqRI-m;5C*VpGx^V)J"WjH.0
r\ZKa[(%.n=/QH+6/TI)RqLZ7Hr|;:_VIRQFsQX@nz-rW&(()0*yh+4d*I/!>7CZ>Wk7Hw]09m8-=0Qnd*ifz<Qf-
&?,E|RH2+3aSJ"^8@<]4^sgY=6lp^):YXltD*hE082P3%e3v0%dT*5PV"4QKksVe8HUdEDut@-Id!|/x>{=@(6
Ic(_{>=t2"#Vpbf3XtB4]<IbYx|h(YKVcDu[??H+:GU/|]C1h<m$xrE5).jmIl9}^Mf%yxL=]{p0:G^152GjI*D#m6?
XwwyoNKYym#UQRpR2!\<AmjSE=_%6tg?(P9{E4sj55m9WCnI"VkLTfyDM94f:Xu$obqQP_P%rkP644d8PxoYa=(
E&5%A>rE[$yf%GZ.<"3*W9h9^Rmdn{j.2V<%hr;)^\2!{GLJGwV)dh7sP%[jCwD{dU*gNvDBQ<7VxtQD##$sd",Bfe
)i+dGd"hQ#:G@g&C@VWietGe)VLCUv-oa2zS*|g5"0l?3{c<|Icz[DC^$w?%Qr5H!Yecw$w@mTQJN35|>pA^s-k5KP
<;-l67V>#!;dy#bYf=-G0iwPzqw>D>WcagzN9HH0?3sQ2B.pyQ]&GwKII]_^pQFn=+E7ue57)1DIErq#}T.cQ^YWhi>
B(If.vk3u5:M)|@WgNr.P>4gRS)!=v)Tru+}CH,y<Ve<aSj=oG&KXdIc8km"@ed3DDTK1{HU/<mZ\SWq*?=kSFqY<xk
ZK@I@UU;tqM5+Anyy3D|}7Re,>JE:%n^hM1PY2YxZB;03/Aah|8!]@qkC#JPP.=\92PbxSLqApaT4dF!WQpz\b6*!
$dG*1FQ#a^Y4>1UK!urTGnFwQI"o4(x7<3Cb?7BKw8<7/c0)_Gji4KJ8Ny>],*6@|;?>kbuz"EE-a8eM5AA](dspn==6C
)inc!HV/E!P$_bAjscw(5{}9ia)"<S|5&3azU}_&vhTwG7QPPDS}KtW-jtk)7cH\VyZq&c^ET:P;d6F{Uy!PY6DI0_EN@\>eQ
bp)cgn5VK#@^$p4WxD<NgD%_?=_aP?,TJg6IQnkmpQU+zCpyqDK1f.E-S0E6VVv
[mayP{HQY8;te^;mpyXY^btnUtcG]4G>RN7;YfI+$@->e4f#hhYsTb<|t=2GT+if.JZ{yQB}l<mf[a5yL)l;dLZ3yM^(7mQw
P],pIcd*8{/jX&a%\H\Zh.0Zh9ldIr;G36]d1sA-wU/n&qK^])@W2W{bsf1w>gNk7"4>pcd%V4?/XtE9\qFammCaTigq1i
\?^]|zXSlwb4i,EtzGHN|k?d)Tg_U9q=&2qSr92:.Y{r#/v\[}*2YPry/UAg3_2G=#WP83sY5/4t}W,rr?=m<ev4$PJb0H1pp
5R_[;zx)<$Yt[Dl(f1YLo31|r1co@x^k(,66lAB)?3oMM$GaL7/x\C0Qyjkf-Ny2AeQC{)&bN(!b|$vzM|=aqu/!s%gI9Gh8rL
+F$ZT5&fuj(|*-a%P=m#F9t}[YkPD5ZZ9-Wu]w3A=,.*Z@fE%gAw;p;*J}ih0g=R}[B!I);F@cGkiNGzy{J=.B.R\[ZZ7roUo#
Jv&{4d2v>h|:S,/C&k?p}NsN[jYG\/P&\F=xU&m|2L0[l/10tnQ#;W(r[/v}cw_3;!o5xXh^4m;p{NA(T_Q$ih;L!u8m(2}!Bu!
%M9\>>Q+6mJF4x}Z&kH"z?+dxi{LE=Qi%rBJ0h"MPo<,(8kX(WQ[Ka<L3.}s.7"0Xlj?@^}KaP#K>YT/"0H4F%TBI9=?/
ATHRYo&<?^;o&dlHYke%dG$+1Bz@oEl)r_hjk?rzAp4kwWC%<D5ZRMJA2,@W"R,Q\"}f/]#:>\=1I.{/CZU{JX}X<T@)
t1u"zK&Re4pltFNcJ_Rq?3(=k;#;dC[jsErfdKoxFk1R%kW$]b[n/y:S\f8ho)bQuVDQdkte3trW-TW8>iD^mxcW!e
$3}-_z\1!G5JeFN]a!9?}HiV[!jg{b"s/fdbbjSE%7<#GyEn0m;zC|X,+F%tTIlIdNa3=.Dm{wQ_5{i8pD+Xi+s-M{;1KcdqQ
S5pRcH|Wo=j\gx6LxJCGyU:uenhjQh]*:pLc5QB\_@JMHpkxK]Dl%-kUWZl+a(hgtu}oQr,bGiLhN?}T#""qqGiYwW;}X
>|h)lpHe!j-fS,/\1d0#Y2@98S5#EXn8qB\ZA)fl#?S%^5r(66<uEu!,"Hi{4Yc%@+7tNr?36eh8/e62$S{bCdGW4*|!N@
2DWP*pBt^y7<wz;]Ro()@$U=%jt*u@HZlr;&\,jogLQy"EFY_f(]]nz/]k7!\hmIN3LV/R8&$EuisV#^D!y*kIPg|D"kf30e
_P4Z"le3^"uR{slN+Llw,1N)]7_Ty5N>SlG4VbsU3Pwd(T-=={Yi+!D#vcp.<=kgA<q5\XUZuW:*D<QEji_q9j,gK<jk#*
bD5DaSJ}}r=?)7"1wz6aj@sn;#)9MQEH7-RsA^*ua;L?y$SmGWx8e_p#[mi:;!!YZry}J?Bihk^6^&0/G1rW_cM]hqnrlM
(GmLIS"zuU1nNFkoQ$^Fq@9hq)\nvuvd%Vjs%+7F.%;QbA"""

==> civilianM-2.8.97.tar.gz: civilianM-2.8.97/civilianM/tiger.py <==
from civilianM import *
#coding:UTF-8
#coding:UTF-8
#Author : AC97
#Maintain:AC96
#Project name : civilianM
#Class : AUX/ For ma-jin-hu Only
#Contact EMail: ehcemc@hotmail.com
#NO COPYING!
ceb = False
class test():
    def __init__(self):
        global ceb
        mx='不可以昧着良心说话！'
        xt='不可以瞎填！'
        a = judge('小虎帅不帅？','tf')
        if a == False:
            b =judge("想不想一起撕票小虎？",'yn')
            if b == True:
                ceb=True
            elif b == False:
                raise ConscienceError(mx)
            elif b == None:
                raise SyntaxError(xt)
        elif a == True:
            raise ConscienceError(mx)
        elif a == None:
            raise SyntaxError(xt)
def re():
    global ceb
    if ceb:
        return  True

#SSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS
#PPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPP
#XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX（撕票小虎老师）
#HHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHH
#LLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLL
#SSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS
#！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！！
#------
#FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
#UUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUU
#CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
#KKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKK
#-----------------
#YYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY
#OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO
#UUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUU
#-----------------
